Label types, filtering, validation, and module-level defaults.
Labels are sentinel values created with the crate::label attribute
macro. Tests are filtered by the SKULD_LABELS environment variable
(boolean expression with &, |, !, and grouping, matched
case-insensitively).
Structs
- Label
- A test label. Created via the
crate::labelattribute macro. - Label
Filter - A boolean expression over label names that can be matched against a set of labels to determine whether a test should be selected.
- Module
Labels - Default labels for all tests in a module. Registered by
crate::default_labels!.